==> jc-1.4.0.tar.gz: javax/security/auth/callback/TextOutputCallback.h <==
// public class javax.security.auth.callback.TextOutputCallback

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 514937a9abf4a4f6 javax_security_auth_callback_TextOutputCallback

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_callback_TextOutputCallback_H_
#define _JC_javax_security_auth_callback_TextOutputCallback_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_auth_callback_TextOutputCallback$sub_refs	_jc_javax_security_auth_callback_TextOutputCallback$sub_refs;
typedef struct _jc_javax_security_auth_callback_TextOutputCallback$sub_nonrefs	_jc_javax_security_auth_callback_TextOutputCallback$sub_nonrefs;
typedef struct _jc_javax_security_auth_callback_TextOutputCallback$refs	_jc_javax_security_auth_callback_TextOutputCallback$refs;
typedef struct _jc_javax_security_auth_callback_TextOutputCallback$nonrefs	_jc_javax_security_auth_callback_TextOutputCallback$nonrefs;
typedef struct _jc_javax_security_auth_callback_TextOutputCallback$object	_jc_javax_security_auth_callback_TextOutputCallback$object;

typedef struct _jc_javax_security_auth_callback_TextOutputCallback$fields_struct	_jc_javax_security_auth_callback_TextOutputCallback$fields_struct;
typedef const struct _jc_javax_security_auth_callback_TextOutputCallback$vmethods	_jc_javax_security_auth_callback_TextOutputCallback$vmethods;
typedef const struct _jc_javax_security_auth_callback_TextOutputCallback$vtable	_jc_javax_security_auth_callback_TextOutputCallback$vtable;
typedef const struct _jc_javax_security_auth_callback_TextOutputCallback$vtype	_jc_javax_security_auth_callback_TextOutputCallback$vtype;

// Class fields structure
struct _jc_javax_security_auth_callback_TextOutputCallback$fields_struct {
	jint	ERROR;
	jint	INFORMATION;
	jint	WARNING;
};
extern _jc_javax_security_auth_callback_TextOutputCallback$fields_struct _jc_javax_security_auth_callback_TextOutputCallback$class_fields;

// Constructors
extern void _jc_javax_security_auth_callback_TextOutputCallback$method$_init$206934d97c5ba451(_jc_env *, struct _jc_javax_security_auth_callback_TextOutputCallback$object *, jint, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_callback_TextOutputCallback$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_javax_security_auth_callback_TextOutputCallback$object *);
extern jint _jc_javax_security_auth_callback_TextOutputCallback$method$getMessageType$984d8b1e6b2f13c8(_jc_env *, struct _jc_javax_security_auth_callback_TextOutputCallback$object *);
extern void _jc_javax_security_auth_callback_TextOutputCallback$method$setMessage$1e7a6e01030160bb(_jc_env *, struct _jc_javax_security_auth_callback_TextOutputCallback$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_callback_TextOutputCallback$method_info$getMessage$13aaf240efc902b1;
extern _jc_method _jc_javax_security_auth_callback_TextOutputCallback$method_info$getMessageType$984d8b1e6b2f13c8;
extern _jc_method _jc_javax_security_auth_callback_TextOutputCallback$method_info$setMessage$1e7a6e01030160bb;

// Virtual methods structure
struct _jc_javax_security_auth_callback_TextOutputCallback$vmethods {
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_javax_security_auth_callback_TextOutputCallback$object *);
	jint	(*getMessageType$984d8b1e6b2f13c8)(_jc_env *, struct _jc_javax_security_auth_callback_TextOutputCallback$object *);
	void	(*setMessage$1e7a6e01030160bb)(_jc_env *, struct _jc_javax_security_auth_callback_TextOutputCallback$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_javax_security_auth_callback_TextOutputCallback$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_callback_TextOutputCallback$vmethods	javax_security_auth_callback_TextOutputCallback;
};

// Vtype
struct _jc_javax_security_auth_callback_TextOutputCallback$vtype {
	_jc_type			type;
	_jc_javax_security_auth_callback_TextOutputCallback$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_callback_TextOutputCallback$sub_refs {
	struct _jc_java_lang_String$object	*message;
};

// Reference instance fields (object)
struct _jc_javax_security_auth_callback_TextOutputCallback$refs {
    _jc_javax_security_auth_callback_TextOutputCallback$sub_refs	javax_security_auth_callback_TextOutputCallback;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_callback_TextOutputCallback$sub_nonrefs {
	jint	messageType;
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_callback_TextOutputCallback$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_callback_TextOutputCallback$sub_nonrefs	javax_security_auth_callback_TextOutputCallback;
};

// Object instance structure
struct _jc_javax_security_auth_callback_TextOutputCallback$object {
	_jc_javax_security_auth_callback_TextOutputCallback$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_callback_TextOutputCallback$vtype	*vtype;
	_jc_javax_security_auth_callback_TextOutputCallback$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_callback_TextOutputCallback$vtype _jc_javax_security_auth_callback_TextOutputCallback$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_callback_TextOutputCallback, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_callback_TextOutputCallback$class_object;

#endif	/* _JC_javax_security_auth_callback_TextOutputCallback_H_ */

==> jc-1.4.6.tar.gz: javax/security/auth/callback/TextOutputCallback.h <==
// public class javax.security.auth.callback.TextOutputCallback

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 514937a9abf4a4f6 javax_security_auth_callback_TextOutputCallback

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_callback_TextOutputCallback_H_
#define _JC_javax_security_auth_callback_TextOutputCallback_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_auth_callback_TextOutputCallback$sub_refs	_jc_javax_security_auth_callback_TextOutputCallback$sub_refs;
typedef struct _jc_javax_security_auth_callback_TextOutputCallback$sub_nonrefs	_jc_javax_security_auth_callback_TextOutputCallback$sub_nonrefs;
typedef struct _jc_javax_security_auth_callback_TextOutputCallback$refs	_jc_javax_security_auth_callback_TextOutputCallback$refs;
typedef struct _jc_javax_security_auth_callback_TextOutputCallback$nonrefs	_jc_javax_security_auth_callback_TextOutputCallback$nonrefs;
typedef struct _jc_javax_security_auth_callback_TextOutputCallback$object	_jc_javax_security_auth_callback_TextOutputCallback$object;

typedef struct _jc_javax_security_auth_callback_TextOutputCallback$fields_struct	_jc_javax_security_auth_callback_TextOutputCallback$fields_struct;
typedef const struct _jc_javax_security_auth_callback_TextOutputCallback$vmethods	_jc_javax_security_auth_callback_TextOutputCallback$vmethods;
typedef const struct _jc_javax_security_auth_callback_TextOutputCallback$vtable	_jc_javax_security_auth_callback_TextOutputCallback$vtable;
typedef const struct _jc_javax_security_auth_callback_TextOutputCallback$vtype	_jc_javax_security_auth_callback_TextOutputCallback$vtype;

// Class fields structure
struct _jc_javax_security_auth_callback_TextOutputCallback$fields_struct {
	jint	ERROR;
	jint	INFORMATION;
	jint	WARNING;
};
extern _jc_javax_security_auth_callback_TextOutputCallback$fields_struct _jc_javax_security_auth_callback_TextOutputCallback$class_fields;

// Constructors
extern void _jc_javax_security_auth_callback_TextOutputCallback$method$_init$206934d97c5ba451(_jc_env *, struct _jc_javax_security_auth_callback_TextOutputCallback$object *, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_callback_TextOutputCallback$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_javax_security_auth_callback_TextOutputCallback$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_security_auth_callback_TextOutputCallback$method$getMessageType$984d8b1e6b2f13c8(_jc_env *, struct _jc_javax_security_auth_callback_TextOutputCallback$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_callback_TextOutputCallback$method$setMessage$1e7a6e01030160bb(_jc_env *, struct _jc_javax_security_auth_callback_TextOutputCallback$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_callback_TextOutputCallback$method_info$getMessage$13aaf240efc902b1;
extern _jc_method _jc_javax_security_auth_callback_TextOutputCallback$method_info$getMessageType$984d8b1e6b2f13c8;
extern _jc_method _jc_javax_security_auth_callback_TextOutputCallback$method_info$setMessage$1e7a6e01030160bb;

// Virtual methods structure
struct _jc_javax_security_auth_callback_TextOutputCallback$vmethods {
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_javax_security_auth_callback_TextOutputCallback$object *) _JC_JCNI_ATTR;
	jint	(*getMessageType$984d8b1e6b2f13c8)(_jc_env *, struct _jc_javax_security_auth_callback_TextOutputCallback$object *) _JC_JCNI_ATTR;
	void	(*setMessage$1e7a6e01030160bb)(_jc_env *, struct _jc_javax_security_auth_callback_TextOutputCallback$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_security_auth_callback_TextOutputCallback$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_callback_TextOutputCallback$vmethods	javax_security_auth_callback_TextOutputCallback;
};

// Vtype
struct _jc_javax_security_auth_callback_TextOutputCallback$vtype {
	_jc_type			type;
	_jc_javax_security_auth_callback_TextOutputCallback$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_callback_TextOutputCallback$sub_refs {
	struct _jc_java_lang_String$object	*message;
};

// Reference instance fields (object)
struct _jc_javax_security_auth_callback_TextOutputCallback$refs {
    _jc_javax_security_auth_callback_TextOutputCallback$sub_refs	javax_security_auth_callback_TextOutputCallback;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_callback_TextOutputCallback$sub_nonrefs {
	jint	messageType;
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_callback_TextOutputCallback$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_callback_TextOutputCallback$sub_nonrefs	javax_security_auth_callback_TextOutputCallback;
};

// Object instance structure
struct _jc_javax_security_auth_callback_TextOutputCallback$object {
	_jc_javax_security_auth_callback_TextOutputCallback$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_callback_TextOutputCallback$vtype	*vtype;
	_jc_javax_security_auth_callback_TextOutputCallback$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_callback_TextOutputCallback$vtype _jc_javax_security_auth_callback_TextOutputCallback$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_callback_TextOutputCallback, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_callback_TextOutputCallback$class_object;

#endif	/* _JC_javax_security_auth_callback_TextOutputCallback_H_ */
